import gost_utils


def test_data_get_value():
    data = [
        {
            "params": {
                "data": {
                    "x1": {
                        "x2": "Y"
                    }
                },
                "key": ["x1", "x2", "x3"],
                "last_dict": True,
                "processed_keys": True
            },
            "response": {
                "value": None,
                "is_default": True,
                "last_dict": {"x2": "Y"},
                "processed_keys": ['x1', 'x2']
            }
        },
        {
            "params": {
                "data": {
                    "x1": {
                        "x2": "Y"
                    }
                },
                "key": ["x1", "x2"],
                "last_dict": True,
                "processed_keys": True
            },
            "response": {
                "value": "Y",
                "is_default": False,
                "last_dict": {"x2": "Y"},
                "processed_keys": ['x1', 'x2']
            }
        },
        {
            "params": {
                "data": {
                    "x1": {
                        "x2": "O"
                    }
                },
                "key": ["x1", "x2"],
                "last_dict": False,
                "processed_keys": False
            },
            "response": {
                "value": "O",
                "is_default": False,
                "last_dict": None,
                "processed_keys": None
            }
        },

    ]

    for i in data:
        params = i["params"] 
        result = gost_utils.data.get_value(**params)
        print("result: ", result)
        for res_k, res_v in i["response"].items():
            print(result[res_k], " == ", res_v )
            assert result[res_k] == res_v 



import gost_utils



def test_currency_format():
    data = [
        {
            "params": {
                "value": 1500.5,
                "decimal_places": 2,
                "separator": " ",
                "decimal_point": ".", 
            },
            "response": "1 500.50"
        },
        {
            "params": {
                "value": 15000000.5,
                "decimal_places": 2,
                "separator": " ",
                "decimal_point": ".", 
            },
            "response": "15 000 000.50"
        },
        {
            "params": {
                "value": 10.5,
                "decimal_places": 5,
                "separator": " ",
                "decimal_point": ".", 
            },
            "response": "10.50000"
        },

    ]

    for i in data:
        params = i["params"] 
        result = gost_utils.currency.format(**params)
        print("result: ", result)
        assert result == i["response"] 





# rm -rf dist/ build/ *.egg-info
# python setup.py sdist bdist_wheel

# pip uninstall gost_utils
# pip install .

# twine upload dist/*


from setuptools import setup, find_packages



setup(
    name="gost_utils",
    version="0.1.6",                 # Версія
    description="Many utils",  # Короткий опис
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Steppe_Mammoth",              # Ваше ім'я
    author_email="qwqwqww505@yahoo.com",  # Ваш email
    url="",  # Посилання на репозиторій
    packages=find_packages(include=["utils", "utils.*"]),
    install_requires=[
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',         # Мінімальна версія Python
)
